<?php
/**
 * Blog Personal Plus functions and definitions.
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package Blog_Personal_Plus
 */

if ( ! function_exists( 'blog_personal_plus_setup' ) ) :

	/**
	 * Sets up theme defaults and registers support for various WordPress features.
	 *
	 * @since 1.0.0
	 */
	function blog_personal_plus_setup() {

		// Declare WooCommerce Support
		add_theme_support( 'woocommerce' );
		add_theme_support( 'wc-product-gallery-lightbox' );
		add_theme_support( 'wc-product-gallery-zoom' );
		add_theme_support( 'wc-product-gallery-slider' );
	}

endif;
add_action( 'after_setup_theme', 'blog_personal_plus_setup');

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */

function blog_personal_plus_widgets_init() {

	if(class_exists( 'WooCommerce' )):

		register_sidebar( array(

			'name'          => esc_html__( 'Wocommerce Sidebar', 'blog-personal-plus' ),
			'id'            => 'woocommerce-widget',
			'before_widget' => '<section id="%1$s" class="widget %2$s">',
			'after_widget'  => '</section>',
			'before_title'  => '<h2 class="entry-title"></span>',
			'after_title'   => '</span></h2>',
		) );	

	endif;				

}

add_action( 'widgets_init', 'blog_personal_plus_widgets_init' );

if ( ! function_exists( 'blog_personal_plus_enqueue_styles' ) ) :

	/**
	 * Load assets.
	 *
	 * @since 1.0.0
	 */
	function blog_personal_plus_enqueue_styles() {

		wp_enqueue_style( 'blog-personal-parent-style', get_template_directory_uri() . '/style.css' );

		wp_enqueue_style( 'blog-personal-plus', get_stylesheet_uri(), array( 'blog-personal-parent-style' ), '1.0.0' );
	}

endif;

add_action( 'wp_enqueue_scripts', 'blog_personal_plus_enqueue_styles');


function Blog_Personal_Plus_Featured_Action() {

  register_widget( 'Blog_Personal_Plus_Featured' );  

}
add_action( 'widgets_init', 'Blog_Personal_Plus_Featured_Action' );

/**
* 
*  Featured Post Widget
*
**/

class Blog_Personal_Plus_Featured extends WP_Widget {

	function __construct()	{	

		global $control_ops;
		$widget_ops = array(

		  'classname'   => 'featured-post',

		  'description' => esc_html__( 'Displays latest posts or posts from a choosen category.', 'blog-personal-plus' ),

		);	
		parent::__construct( 'Blog_Personal_Plus_Featured',esc_html__( 'Blog: Featured Post', 'blog-personal-plus' ), $widget_ops, $control_ops );
	}

	function form( $instance ) {
		$defaults[ 'title' ]            = '';
        $defaults[ 'show_post_meta' ]	= true;  
        $defaults[ 'category' ]    		= '';           

		$instance = wp_parse_args( (array) $instance, $defaults );
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 3; 
		$title = ( ! empty( $instance['title'] ) ) ? esc_html($instance['title']) : '';	
		$category = isset( $instance['category'] ) ? absint( $instance['category'] ) : 0;
		$show_post_meta = isset( $instance['show_post_meta'] ) ? (bool) $instance['show_post_meta'] : true;
	?>

		<p>
			<label for="<?php echo esc_attr($this->get_field_id( 'title' )); ?>">
				<?php echo esc_html__( 'Title', 'blog-personal-plus' ); ?>	
			</label>
			<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'title' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'title' )); ?>" type="text" value="<?php echo esc_attr($title); ?>" />
		</p>

		<p>
		    <input class="checkbox" type="checkbox"<?php checked( $show_post_meta ); ?> id="<?php echo esc_attr($this->get_field_id( 'show_post_meta' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'show_post_meta' )); ?>" />
		    <label for="<?php echo esc_attr($this->get_field_id( 'show_post_meta' )); ?>">
		    	<?php echo esc_html__( 'Enable Post Meta', 'blog-personal-plus' ); ?>	    	

		    </label>
		</p>	

		<p>
			<label for="<?php echo esc_attr( $this->get_field_id( 'category' ) ); ?>">
				<?php esc_html_e( 'Select Category:', 'blog-personal-plus' ); ?>	

			</label>
			<?php
				wp_dropdown_categories(array(
	                'orderby'         => 'name',
	                'hide_empty'      => 0,
	                'class' 		  => 'widefat',	
					'show_option_none' => '',
					'show_option_all'  => esc_html__('&mdash; Select &mdash;','blog-personal-plus'),
					'name'             => esc_attr($this->get_field_name( 'category' )),
					'selected'         => absint( $category ),         
				) );
			?>
		</p>
	    <p>
	    	<label for="<?php echo esc_attr($this->get_field_id( 'number' )); ?>">
	    		<?php echo esc_html__( 'Choose Number', 'blog-personal-plus' );?> 
	    	</label>
	    	<input class="widefat" id="<?php echo esc_attr($this->get_field_id( 'number' )); ?>" name="<?php echo esc_attr($this->get_field_name( 'number' )); ?>" type="number" step="1" min="1" value="<?php echo esc_attr($number); ?>" max="100" />
	    </p>
	<?php 
	}

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;    
		$instance['title'] = sanitize_text_field( $new_instance['title'] ); 
        $instance['category'] = absint( $new_instance['category'] );   
        $instance['number'] = (int) $new_instance['number'];
		$instance['show_post_meta'] = (bool) $new_instance['show_post_meta']; 
		return $instance;
	}

    function widget( $args, $instance ) {
    	extract( $args ); 
        $show_post_meta = isset( $instance['show_post_meta'] ) ? $instance['show_post_meta'] : true;
        $title = ( ! empty( $instance['title'] ) ) ? esc_html($instance['title']) : '';
        $category  = isset( $instance[ 'category' ] ) ? $instance[ 'category' ] : '';
        $number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5; 
        echo $before_widget; ?>
        	<div class="container">
        	<?php if( !empty( $title ) ): ?>
				<header class="entry-header heading">
					<h2 class="entry-title"><?php echo esc_html( $title );?></h2>
				</header>
			<?php endif; ?>	
				<?php $slider_args = array(
				    'posts_per_page' => absint( $number ),
				    'post_type' => 'post',
				    'post_status' => 'publish',
				    'post__not_in' => get_option( 'sticky_posts' ),     

				);
				if ( absint( $category ) > 0 ) {
				  $slider_args['cat'] = absint( $category );
				}
		        $the_query = new WP_Query( $slider_args );
		        if ($the_query->have_posts()) : ?>
					<?php while ( $the_query->have_posts() ) : $the_query->the_post(); ?>
						<article class="post">
							<?php if ( has_post_thumbnail() ): ?>
								<figure class="featured-image">
									<?php the_post_thumbnail( 'blog-personal-featured' );?>
								</figure>
							<?php endif;?>
							<div class="post-content">
								<header class="entry-header">
									<?php if ( true == $show_post_meta ) { ?>
										<div class="entry-meta">
											<?php blog_personal_entry_footer(); 
											blog_personal_posted_on();?>
										</div>
									<?php } ?>
									<h3 class="entry-title"> <a href="<?php the_permalink();?>"><?php the_title();?></a> </h3>
								</header>
							</div> 
						</article>
					<?php endwhile; 
					wp_reset_postdata();?>
				<?php endif;; ?>
    		</div>
        <?php echo $after_widget;
    } 
}
